==> moodle-1.4.3-pgsql.tgz: moodle/lang/ca/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 unstable development (2004083000)


$string['about'] = 'Referent a aquest editor';
$string['absbottom'] = 'Absbottom';
$string['middle'] = 'middle';
$string['address'] = 'Adrea';
$string['alignment'] = 'Alineaci';
$string['alternatetext'] = 'Text alternatiu';
$string['anchorhelp'] = 'Noms crea l\'ncora. Heu de crear l\'enlla a m.';
$string['anchorname'] = 'Nom de l\'ncora';
$string['anchors'] = 'ncores';
$string['baseline'] = 'Lnia base';
$string['bold'] = 'Negreta';
$string['borderthickness'] = 'Gruix del contorn';
$string['bottom'] = 'Bottom';
$string['browse'] = 'Navega';
$string['cancel'] = 'Cancella';
$string['cellpadding'] = 'Cellpadding';
$string['cellspacing'] = 'Cellspacing';
$string['choosechar'] = 'Tria un carcter';
$string['chooseicon'] = 'Tria una icona per inserir';
$string['close'] = 'Tanca';
$string['cols'] = 'Cols';
$string['copy'] = 'Copia la selecci';
$string['createanchor'] = 'Crea ncora';
$string['createfolder'] = 'Crea una carpeta';
$string['createlink'] = 'Insereix un enlla web';
$string['cut'] = 'Talla la selecci';
$string['delete'] = 'Suprimeix';
$string['filebrowser'] = 'Explorador de fitxers';
$string['forecolor'] = 'Color de la lletra';
$string['fullscreen'] = 'Editor a pantalla completa';
$string['heading'] = 'Encapalament';
$string['height'] = 'Alada';
$string['hilitecolor'] = 'Color de fons';
$string['horizontal'] = 'Horitzontal';
$string['horizontalrule'] = 'Filet horitzontal';
$string['htmlmode'] = 'Commuta a font HTML';
$string['imageurl'] = 'URL de la imatge';
$string['indent'] = 'Augmenta el sagnat';
$string['insertchar'] = 'Insereix un carcter especial';
$string['insertimage'] = 'Insereix una imatge';
$string['insertlink'] = 'Insereix un enlla';
$string['insertsmile'] = 'Insereix una emoticona';
$string['inserttable'] = 'Insereix una taula';
$string['italic'] = 'Cursiva';
$string['justifycenter'] = 'Justifica al centre';
$string['justifyfull'] = 'Justifica a ambds costats';
$string['justifyleft'] = 'Justifica a l\'esquerra';
$string['justifyright'] = 'Justifica a la dreta';
$string['layout'] = 'Format';
$string['left'] = 'Left';
$string['lefttoright'] = 'Sentit d\'esquerra a dreta';
$string['linkproperties'] = 'Propietats de l\'enlla';
$string['linktarget'] = 'Objectiu';
$string['linktargetblank'] = 'Finestra nova';
$string['linktargetnone'] = 'Cap';
$string['linktargetother'] = 'Altres (no funciona)';
$string['linktargetself'] = 'El mateix marc';
$string['linktargettop'] = 'La mateixa finestra';
$string['linktitle'] = 'Ttol';
$string['linkurl'] = 'URL';
$string['middle'] = 'Centre';
$string['minimize'] = 'Minimitza l\'editor';
$string['move'] = 'Mou';
$string['normal'] = 'Normal';
$string['notimage'] = 'El fitxer seleccionat no s una imatge. Si us plau trieu-ne un altre!';
$string['notset'] = 'No seleccionat';
$string['ok'] = 'D\'acord';
$string['orderedlist'] = 'Llista numerada';
$string['outdent'] = 'Disminueix el sagnat';
$string['paste'] = 'Enganxa des del porta-retalls';
$string['path'] = 'Cam';
$string['percent'] = 'Percentatge';
$string['pixels'] = 'Pxels';
$string['popupeditor'] = 'Amplia l\'editor';
$string['preformatted'] = 'Preformatat';
$string['preview'] = 'Visualitzaci prvia';
$string['properties'] = 'Propietats';
$string['redo'] = 'Refs la darrera acci';
$string['removelink'] = 'Suprimeix enlla';
$string['rename'] = 'Canvia el nom';
$string['right'] = 'Right';
$string['righttoleft'] = 'Sentit de dreta a esquerra';
$string['rows'] = 'Files';
$string['selectcolor'] = 'Selecciona el color';
$string['selection'] = 'Selecci';
$string['showhelp'] = 'Ajuda de l\'editor';
$string['size'] = 'Mida';
$string['spacing'] = 'Espaiament';
$string['strikethrough'] = 'Barrat';
$string['subscript'] = 'Subndex';
$string['superscript'] = 'Superndex';
$string['textindicator'] = 'Estil actual';
$string['textmode'] = 'Esteu en MODE TEXT. Utilitzeu el bot [<>] per tornar al MODE WYSIWYG.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Top';
$string['type'] = 'Tipus';
$string['underline'] = 'Subratllat';
$string['undo'] = 'Desfs la darrera acci';
$string['unorderedlist'] = 'Llista no numerada';
$string['upload'] = 'Penja';
$string['vertical'] = 'Vertical';
$string['width'] = 'Amplada';
$string['wordclean'] = 'Neteja l\'HTML del Word';
$string['zip'] = 'Zip';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/ca/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005041101)


$string['about'] = 'Referent a aquest editor';
$string['absbottom'] = 'Absbottom';
$string['address'] = 'Adrea';
$string['alertnoselectedtext'] = 'Abans heu de seleccionar el text';
$string['alignment'] = 'Alineaci';
$string['alternatetext'] = 'Text alternatiu';
$string['anchorhelp'] = 'Noms crea l\'ncora. Heu de crear l\'enlla a m.';
$string['anchorname'] = 'Nom de l\'ncora';
$string['anchors'] = 'ncores';
$string['baseline'] = 'Lnia base';
$string['bold'] = 'Negreta';
$string['borderthickness'] = 'Gruix del contorn';
$string['bottom'] = 'Bottom';
$string['browse'] = 'Navega';
$string['cancel'] = 'Cancella';
$string['cellpadding'] = 'Cellpadding';
$string['cellspacing'] = 'Cellspacing';
$string['choosechar'] = 'Tria un carcter';
$string['chooseicon'] = 'Tria una icona per inserir';
$string['close'] = 'Tanca';
$string['closeafterreplace'] = 'Tanca desprs de reemplaar';
$string['cols'] = 'Cols';
$string['copy'] = 'Copia la selecci';
$string['createanchor'] = 'Crea ncora';
$string['createfolder'] = 'Crea una carpeta';
$string['createlink'] = 'Insereix un enlla web';
$string['cut'] = 'Talla la selecci';
$string['delete'] = 'Suprimeix';
$string['filebrowser'] = 'Explorador de fitxers';
$string['findwhat'] = 'Cerca';
$string['fontname'] = 'Nom de la font';
$string['fontsize'] = 'Mida de la lletra';
$string['forecolor'] = 'Color de la lletra';
$string['formatblock'] = 'Format';
$string['fullscreen'] = 'Editor a pantalla completa';
$string['heading'] = 'Encapalament';
$string['height'] = 'Alada';
$string['hilitecolor'] = 'Color de fons';
$string['horizontal'] = 'Horitzontal';
$string['horizontalrule'] = 'Filet horitzontal';
$string['htmlmode'] = 'Commuta a font HTML';
$string['imageurl'] = 'URL de la imatge';
$string['indent'] = 'Augmenta el sagnat';
$string['insertchar'] = 'Insereix un carcter especial';
$string['insertimage'] = 'Insereix una imatge';
$string['insertlink'] = 'Insereix un enlla';
$string['insertsmile'] = 'Insereix una emoticona';
$string['inserttable'] = 'Insereix una taula';
$string['italic'] = 'Cursiva';
$string['itemsreplaced'] = 'elements reemplaats';
$string['justifycenter'] = 'Justifica al centre';
$string['justifyfull'] = 'Justifica a ambds costats';
$string['justifyleft'] = 'Justifica a l\'esquerra';
$string['justifyright'] = 'Justifica a la dreta';
$string['layout'] = 'Format';
$string['left'] = 'Left';
$string['lefttoright'] = 'Sentit d\'esquerra a dreta';
$string['linkproperties'] = 'Propietats de l\'enlla';
$string['linktarget'] = 'Objectiu';
$string['linktargetblank'] = 'Finestra nova';
$string['linktargetnone'] = 'Cap';
$string['linktargetother'] = 'Altres (no funciona)';
$string['linktargetself'] = 'El mateix marc';
$string['linktargettop'] = 'La mateixa finestra';
$string['linktitle'] = 'Ttol';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Majscules/minscules';
$string['middle'] = 'Centre';
$string['minimize'] = 'Minimitza l\'editor';
$string['move'] = 'Mou';
$string['nolink'] = 'Impedir enllaos automtics';
$string['normal'] = 'Normal';
$string['notimage'] = 'El fitxer seleccionat no s una imatge. Si us plau trieu-ne un altre.';
$string['notset'] = 'No definit';
$string['ok'] = 'D\'acord';
$string['options'] = 'Opcions';
$string['orderedlist'] = 'Llista numerada';
$string['outdent'] = 'Disminueix el sagnat';
$string['paste'] = 'Enganxa des del porta-retalls';
$string['path'] = 'Cam';
$string['percent'] = 'Percentatge';
$string['pixels'] = 'Pxels';
$string['popupeditor'] = 'Amplia l\'editor';
$string['preformatted'] = 'Preformatat';
$string['preview'] = 'Visualitzaci prvia';
$string['properties'] = 'Propietats';
$string['redo'] = 'Refs la darrera acci';
$string['regularexpressions'] = 'Utilitza expressions regulars';
$string['removelink'] = 'Suprimeix enlla';
$string['rename'] = 'Canvia el nom';
$string['replaceall'] = 'Reemplaa-ho tot';
$string['replacewith'] = 'Reemplaa';
$string['right'] = 'Right';
$string['righttoleft'] = 'Sentit de dreta a esquerra';
$string['rows'] = 'Files';
$string['searchandreplace'] = 'Cerca i reemplaa';
$string['searchnotfound'] = 'No s\'ha trobat la cadena cercada';
$string['selectcolor'] = 'Selecciona el color';
$string['selection'] = 'Selecci';
$string['showhelp'] = 'Ajuda de l\'editor';
$string['size'] = 'Mida';
$string['spacing'] = 'Espaiament';
$string['strikethrough'] = 'Barrat';
$string['subscript'] = 'Subndex';
$string['superscript'] = 'Superndex';
$string['textindicator'] = 'Estil actual';
$string['textmode'] = 'Esteu en MODE TEXT. Utilitzeu el bot [<>] per tornar al MODE WYSIWYG.';
$string['texttop'] = 'Texttop';
$string['top'] = 'Top';
$string['type'] = 'Tipus';
$string['underline'] = 'Subratllat';
$string['undo'] = 'Desfs la darrera acci';
$string['unorderedlist'] = 'Llista no numerada';
$string['upload'] = 'Penja';
$string['vertical'] = 'Vertical';
$string['width'] = 'Amplada';
$string['wordclean'] = 'Neteja l\'HTML del Word';
$string['zip'] = 'Zip';

?>
